Foodista | Recipes, Cooking Tips, and Food News | British Treacle Tart

Jump to Navigation

## Search form

Search

# British Treacle Tart

Photo: Leah Rodrigues

## Ingredients

Pastry Crust:
1 3/4 cups all-purpose flour
1/2 teaspoon salt
1/4 cup confectioner’s sugar
5 ounces unsalted butter (11 tbs), cut into small cubes
1 large egg, lightly beaten
Filling:
10 ounces golden syrup
1 tablespoon molasses
1 Zest and juice of lemon
4 medium eggs
1 ounce fresh bread crumbs

## Preparation

1
Combine flour, salt and confectioner’s sugar in a large bowl. Using tips of fingers, rub butter into flour until it looks mostly like wet sand. Make a well in the middle, and pour in the egg. Gradually work the egg into the flour until a moist dough forms, using the heel of your hand to distribute any remaining large pieces of butter. Shape into a 5-inch disk and cover with plastic wrap. Refrigerate for 1 hour. This can be done in a food processor.
2
Roll out dough into a 13-inch circle. Lay dough into an 11-inch tart pan with a removable bottom, and press against the sides to secure dough. Refrigerate for one hour.
3
Preheat oven to 325° F. Dock the bottom of the crust with a fork, lay a large, crumpled piece of parchment on top, and pour in pie weights (or a pound of dried beans). Bake for 25 minutes, until crust is a light golden brown. Set aside.
4
Increase the temperature to 350 F
5
Mix together the golden syrup and molasses with the lemon juice. Beat the eggs in a bowl and add to the treacle mixture. Finally stir in the bread crumbs.
6
Pour the mixture into the prepared tart case.
7
Bake for 20 – 25 minutes until the crust and filling are golden brown and firm to the touch. You may have to cover the crust with aluminum foil to keep it from getting too brown or burning.
8
Serve warm with crème fraiche which balances really well with the sweetness of the tart or a good vanilla ice cream.
.
Place your ad here
Loading...
Tweet
Pin It

## About

You can use pre-made pie dough if short on time. Golden syrup may be found online or in specialty food stores.

## Yield:

1 servings

## Added:

Monday, June 27, 2011 - 11:05am

## Creator:

Leah Rodrigues

## Related Cooking Videos

ROUXBE COOKING SCHOOL & COOKING CLASSES